summaryrefslogtreecommitdiff
path: root/filter
diff options
context:
space:
mode:
authorTor Lillqvist <tml@iki.fi>2013-05-15 10:42:04 +0300
committerTor Lillqvist <tml@iki.fi>2013-05-15 11:14:28 +0300
commitcb6d67c21f11811c5bc023b9565c1c1b1f4081fa (patch)
treeff8a4b192a2ca846d32111732563432244135910 /filter
parent1a357b7394ac7b48b72821bff1aae4706265d7a4 (diff)
Spelling "separate" (etc) correctly is hard
Diffstat (limited to 'filter')
-rw-r--r--filter/source/config/cache/filtercache.cxx6
-rw-r--r--filter/source/config/cache/filtercache.hxx2
-rw-r--r--filter/source/config/tools/split/FCFGSplit.cfg4
-rw-r--r--filter/source/config/tools/split/FCFGSplit.java30
-rw-r--r--filter/source/config/tools/split/SplitterData.java4
-rw-r--r--filter/source/flash/swfwriter1.cxx10
6 files changed, 28 insertions, 28 deletions
diff --git a/filter/source/config/cache/filtercache.cxx b/filter/source/config/cache/filtercache.cxx
index 8fb4412abaa0..f4251c3c1c1c 100644
--- a/filter/source/config/cache/filtercache.cxx
+++ b/filter/source/config/cache/filtercache.cxx
@@ -1364,7 +1364,7 @@ void FilterCache::impl_load(EFillState eRequiredState)
::osl::ResettableMutexGuard aLock(m_aLock);
// Attention: Detect services are part of the standard set!
- // So there is no need to handle it seperatly.
+ // So there is no need to handle it separately.
// ------------------------------------------
// a) The standard set of config value is needed.
@@ -2340,13 +2340,13 @@ CacheItem FilterCache::impl_readOldItem(const css::uno::Reference< css::containe
OUStringList FilterCache::impl_tokenizeString(const OUString& sData ,
- sal_Unicode cSeperator)
+ sal_Unicode cSeparator)
{
OUStringList lData ;
sal_Int32 nToken = 0;
do
{
- OUString sToken = sData.getToken(0, cSeperator, nToken);
+ OUString sToken = sData.getToken(0, cSeparator, nToken);
lData.push_back(sToken);
}
while(nToken >= 0);
diff --git a/filter/source/config/cache/filtercache.hxx b/filter/source/config/cache/filtercache.hxx
index e28b88a3b54a..7305c488a477 100644
--- a/filter/source/config/cache/filtercache.hxx
+++ b/filter/source/config/cache/filtercache.hxx
@@ -1001,7 +1001,7 @@ class FilterCache : public BaseLock
/** TODO */
OUStringList impl_tokenizeString(const OUString& sData ,
- sal_Unicode cSeperator);
+ sal_Unicode cSeparator);
//---------------------------------------
diff --git a/filter/source/config/tools/split/FCFGSplit.cfg b/filter/source/config/tools/split/FCFGSplit.cfg
index 745b781dd27d..69d90adec6eb 100644
--- a/filter/source/config/tools/split/FCFGSplit.cfg
+++ b/filter/source/config/tools/split/FCFGSplit.cfg
@@ -68,7 +68,7 @@ subdir_contenthandlers = contenthandlers
# Enable/Disable grouping of filter fragments and using
# of specialized sub directories.
#------------------------------------------------------
-seperate_filters_by_module = false
+separate_filters_by_module = false
#------------------------------------------------------
# The following defines specify system directories
@@ -76,7 +76,7 @@ seperate_filters_by_module = false
# Every of these sub dir willl be used to generate
# groups of filter fragments there.
# Note: These sub directories are used only if
-# "seperate_filters_by_module" is set to true!
+# "separate_filters_by_module" is set to true!
#------------------------------------------------------
subdir_module_swriter = swriter
subdir_module_sweb = sweb
diff --git a/filter/source/flash/swfwriter1.cxx b/filter/source/flash/swfwriter1.cxx
index 52c29b9e0329..f19f69826e52 100644
--- a/filter/source/flash/swfwriter1.cxx
+++ b/filter/source/flash/swfwriter1.cxx
@@ -727,9 +727,9 @@ void Writer::Impl_writeText( const Point& rPos, const String& rText, const sal_I
}
// -----------------------------------------------------------------------------
-// AS: Because JPEGs require the alpha channel provided seperately (JPEG does not
-// natively support alpha channel, but SWF lets you provide it seperately), we
-// extract the alpha channel into a seperate array here.
+// AS: Because JPEGs require the alpha channel provided separately (JPEG does not
+// natively support alpha channel, but SWF lets you provide it separately), we
+// extract the alpha channel into a separate array here.
void getBitmapData( const BitmapEx& aBmpEx, sal_uInt8*& tgadata, sal_uInt8*& tgaAlphadata, sal_uInt32& nWidth, sal_uInt32& nHeight )
{
if( !aBmpEx.IsEmpty() )
@@ -830,7 +830,7 @@ sal_uInt16 Writer::defineBitmap( const BitmapEx &bmpSource, sal_Int32 nJPEGQuali
#endif
// AS: SWF files let you provide an Alpha mask for JPEG images, but we have
- // to ZLIB compress the alpha channel seperately.
+ // to ZLIB compress the alpha channel separately.
uLong alpha_compressed_size = 0;
sal_uInt8 *pAlphaCompressed = NULL;
if (bmpSource.IsAlpha() || bmpSource.IsTransparent())
@@ -1004,7 +1004,7 @@ void Writer::Impl_writeBmp( sal_uInt16 nBitmapId, sal_uInt32 width, sal_uInt32 h
void Writer::Impl_writeJPEG(sal_uInt16 nBitmapId, const sal_uInt8* pJpgData, sal_uInt32 nJpgDataLength, sal_uInt8 *pAlphaCompressed, sal_uInt32 alpha_compressed_size )
{
- // AS: Go through the actuall JPEG bits, seperating out the
+ // AS: Go through the actuall JPEG bits, separating out the
// header fields from the actual image fields. Fields are
// identifed by 0xFFXX where XX is the field type. Both
// the header and the image need start and stop (D8 and D9),
diff --git a/filter/source/config/tools/split/FCFGSplit.java b/filter/source/config/tools/split/FCFGSplit.java
index a5668536157f..76a6b1a6b5ee 100644
--- a/filter/source/config/tools/split/FCFGSplit.java
+++ b/filter/source/config/tools/split/FCFGSplit.java
@@ -73,7 +73,7 @@ public class FCFGSplit
private static final java.lang.String CFGKEY_SUBDIR_FRAMELOADERS = "subdir_frameloaders" ;
private static final java.lang.String CFGKEY_SUBDIR_CONTENTHANDLERS = "subdir_contenthandlers" ;
- private static final java.lang.String CFGKEY_SEPERATE_FILTERS_BY_MODULE = "seperate_filters_by_module" ;
+ private static final java.lang.String CFGKEY_SEPARATE_FILTERS_BY_MODULE = "separate_filters_by_module" ;
private static final java.lang.String CFGKEY_SUBDIR_MODULE_SWRITER = "subdir_module_swriter" ;
private static final java.lang.String CFGKEY_SUBDIR_MODULE_SWEB = "subdir_module_sweb" ;
@@ -115,7 +115,7 @@ public class FCFGSplit
private static final java.lang.String DEFAULT_SUBDIR_FRAMELOADERS = "FrameLoaders" ;
private static final java.lang.String DEFAULT_SUBDIR_CONTENTHANDLERS = "ContentHandlers" ;
- private static final java.lang.String DEFAULT_SEPERATE_FILTERS_BY_MODULE = "false" ;
+ private static final java.lang.String DEFAULT_SEPARATE_FILTERS_BY_MODULE = "false" ;
private static final java.lang.String DEFAULT_SUBDIR_MODULE_SWRITER = "SWriter" ;
private static final java.lang.String DEFAULT_SUBDIR_MODULE_SWEB = "SWeb" ;
@@ -179,51 +179,51 @@ public class FCFGSplit
/** enable/disable generating of filter groups - separated by
* application modules. */
- private static boolean m_bSeperateFiltersByModule;
+ private static boolean m_bSeparateFiltersByModule;
/** specify the sub directory to generate filter groups
* for the module writer. Will be used only,
- * if m_bSeperateFiltersByModule is set to TRUE.*/
+ * if m_bSeparateFiltersByModule is set to TRUE.*/
private static java.lang.String m_sSubDirModuleSWriter;
/** specify the sub directory to generate filter groups
* for the module writer/web. Will be used only,
- * if m_bSeperateFiltersByModule is set to TRUE.*/
+ * if m_bSeparateFiltersByModule is set to TRUE.*/
private static java.lang.String m_sSubDirModuleSWeb;
/** specify the sub directory to generate filter groups
* for the module writer/global. Will be used only,
- * if m_bSeperateFiltersByModule is set to TRUE.*/
+ * if m_bSeparateFiltersByModule is set to TRUE.*/
private static java.lang.String m_sSubDirModuleSGlobal;
/** specify the sub directory to generate filter groups
* for the module calc. Will be used only,
- * if m_bSeperateFiltersByModule is set to TRUE.*/
+ * if m_bSeparateFiltersByModule is set to TRUE.*/
private static java.lang.String m_sSubDirModuleSCalc;
/** specify the sub directory to generate filter groups
* for the module draw. Will be used only,
- * if m_bSeperateFiltersByModule is set to TRUE.*/
+ * if m_bSeparateFiltersByModule is set to TRUE.*/
private static java.lang.String m_sSubDirModuleSDraw;
/** specify the sub directory to generate filter groups
* for the module impress. Will be used only,
- * if m_bSeperateFiltersByModule is set to TRUE.*/
+ * if m_bSeparateFiltersByModule is set to TRUE.*/
private static java.lang.String m_sSubDirModuleSImpress;
/** specify the sub directory to generate filter groups
* for the module math. Will be used only,
- * if m_bSeperateFiltersByModule is set to TRUE.*/
+ * if m_bSeparateFiltersByModule is set to TRUE.*/
private static java.lang.String m_sSubDirModuleSMath;
/** specify the sub directory to generate filter groups
* for the module chart. Will be used only,
- * if m_bSeperateFiltersByModule is set to TRUE.*/
+ * if m_bSeparateFiltersByModule is set to TRUE.*/
private static java.lang.String m_sSubDirModuleSChart;
/** specify the sub directory to generate filter groups
* for unknown modules - e.g. the graphic filters.
* Will be used only, if m_bSeperateFiltersByModule
* is set to TRUE.*/
private static java.lang.String m_sSubDirModuleOthers;
@@ -376,7 +376,7 @@ public class FCFGSplit
aDataSet.m_aCache = aCache ;
aDataSet.m_nFormat = m_nOutFormat ;
aDataSet.m_sEncoding = m_sOutEncoding ;
- aDataSet.m_bSeperateFiltersByModule = m_bSeperateFiltersByModule;
+ aDataSet.m_bSeparateFiltersByModule = m_bSeparateFiltersByModule;
aDataSet.m_sFragmentExtension = m_sFragmentExtension ;
aDataSet.m_aOutDir = aOutDir ;
@@ -386,7 +386,7 @@ public class FCFGSplit
aDataSet.m_aFragmentDirFrameLoaders = new java.io.File(aOutDir, m_sSubDirFrameLoaders );
aDataSet.m_aFragmentDirContentHandlers = new java.io.File(aOutDir, m_sSubDirContentHandlers);
- if (m_bSeperateFiltersByModule)
+ if (m_bSeparateFiltersByModule)
{
aDataSet.m_aFragmentDirModuleSWriter = new java.io.File(aDataSet.m_aFragmentDirFilters, m_sSubDirModuleSWriter );
aDataSet.m_aFragmentDirModuleSWeb = new java.io.File(aDataSet.m_aFragmentDirFilters, m_sSubDirModuleSWeb );
@@ -500,7 +500,7 @@ public class FCFGSplit
m_sSubDirModuleSChart = aCfg.getProperty(CFGKEY_SUBDIR_MODULE_SCHART , DEFAULT_SUBDIR_MODULE_SCHART );
m_sSubDirModuleOthers = aCfg.getProperty(CFGKEY_SUBDIR_MODULE_OTHERS , DEFAULT_SUBDIR_MODULE_OTHERS );
- m_bSeperateFiltersByModule = new java.lang.Boolean(aCfg.getProperty(CFGKEY_SEPERATE_FILTERS_BY_MODULE , DEFAULT_SEPERATE_FILTERS_BY_MODULE )).booleanValue();
+ m_bSeparateFiltersByModule = new java.lang.Boolean(aCfg.getProperty(CFGKEY_SEPARATE_FILTERS_BY_MODULE , DEFAULT_SEPARATE_FILTERS_BY_MODULE )).booleanValue();
m_bCreateCombineFilterFlag = new java.lang.Boolean(aCfg.getProperty(CFGKEY_CREATE_COMBINE_FILTER_FLAG , DEFAULT_CREATE_COMBINE_FILTER_FLAG )).booleanValue();
m_bRemoveFilterFlagBrowserPreferred = new java.lang.Boolean(aCfg.getProperty(CFGKEY_REMOVE_FILTER_FLAG_BROWSERPREFERRED, DEFAULT_REMOVE_FILTER_FLAG_BROWSERPREFERRED)).booleanValue();
m_bRemoveFilterFlagPreferred = new java.lang.Boolean(aCfg.getProperty(CFGKEY_REMOVE_FILTER_FLAG_PREFERRED , DEFAULT_REMOVE_FILTER_FLAG_PREFERRED )).booleanValue();
@@ -179,51 +179,51 @@ public class FCFGSplit
/** specify the sub directory to generate filter groups
* for unknown modules - e.g. the graphic filters.
- * Will be used only, if m_bSeperateFiltersByModule
+ * Will be used only, if m_bSeparateFiltersByModule
* is set to TRUE.*/
private static java.lang.String m_sSubDirModuleOthers;
diff --git a/filter/source/config/tools/split/SplitterData.java b/filter/source/config/tools/split/SplitterData.java
index 4f85d65791ae..38226a8a61bd 100644
--- a/filter/source/config/tools/split/SplitterData.java
+++ b/filter/source/config/tools/split/SplitterData.java
@@ -58,11 +58,11 @@ public class SplitterData
public java.io.File m_aFragmentDirContentHandlers;
/** enable/disable grouping of filters by its application modules. */
- public boolean m_bSeperateFiltersByModule;
+ public boolean m_bSeparateFiltersByModule;
/** directories to group all filter fragments ... if requested.
* Must be relative to "m_aOutDir/m_aFragmentDirFilters" and
* will be used only, if "m_bSeperateFiltersByModule" is set to true. */
public java.io.File m_aFragmentDirModuleSWriter;
public java.io.File m_aFragmentDirModuleSWeb;
public java.io.File m_aFragmentDirModuleSGlobal;
@@ -58,11 +58,11 @@ public class SplitterData
/** directories to group all filter fragments ... if requested.
* Must be relative to "m_aOutDir/m_aFragmentDirFilters" and
- * will be used only, if "m_bSeperateFiltersByModule" is set to true. */
+ * will be used only, if "m_bSeparateFiltersByModule" is set to true. */
public java.io.File m_aFragmentDirModuleSWriter;
public java.io.File m_aFragmentDirModuleSWeb;